pub enum PostgresWriteMode {
Insert,
Upsert,
Copy,
}Expand description
Persistence mode for PostgreSQL egress.
Variants
Insert
Insert rows into the target table.
Upsert
Upsert rows into the target table using a conflict key.
Copy
Bulk load rows into the target table using COPY FROM STDIN.