KafkaIngress

Struct KafkaIngress 

pub struct KafkaIngress { /* private fields */ }
Minimal blocking Kafka ingress adapter.

This adapter subscribes to one Kafka topic and exposes each consumed record payload as one ingress message.

Implementations

Source

impl KafkaIngress

pub fn new( name: impl Into<String>, brokers: &str, group_id: &str, topic: &str, poll_timeout: Duration, max_message_bytes: usize, ) -> Result<Self, AdapterError>

Create a blocking Kafka ingress adapter.