pub struct KafkaIngress { /* private fields */ }Expand description
Minimal blocking Kafka ingress adapter.
This adapter subscribes to one Kafka topic and exposes each consumed record payload as one ingress message.
Implementations